import torch
from torch.utils.data import Dataset
import numpy as np


# Custom dataset class
class CNNDataset(Dataset):
    def __init__(self, data, truth, n_layers, sensor_dim, transform=False):
        """
        Args:
            data (numpy.ndarray): The input data in the shape (num_samples, sensor_hits)
            truth (numpy.ndarray): The truth in the shape (num_samples, 1)
            n_layers (int): Number of active layers in the input data
            sensor_dim (int): Number of sensors in one dimension per layer
            transform (callable, optional): Optional transform to be applied to the data.
        """
        self.data = np.reshape(data, (-1, 1, n_layers, sensor_dim, sensor_dim))
        self.truth = truth
        self.transform = transform

    def __len__(self):
        return len(self.data)

    def processing(self, sample):
        return sample

    def __getitem__(self, idx):
        sample = self.data[idx]
        label = self.truth[idx]

        if self.transform:
            sample = self.processing(sample)

        return sample, label
