import torch
from torch.utils.data import Dataset
import numpy as np


# Custom dataset class
class MLPDataset(Dataset):
    def __init__(self, data, truth, transform=False):
        """
        Args:
            data (numpy.ndarray): The input data in the shape (num_samples, sensor_hits)
            truth (numpy.ndarray): The truth in the shape (num_samples, 1)
            transform (callable, optional): Optional transform to be applied to the data.
        """
        self.data = data
        self.truth = truth
        self.transform = transform

    def __len__(self):
        return len(self.data)

    def processing(self, sample):
        return sample

    def __getitem__(self, idx):
        sample = self.data[idx]
        label = self.truth[idx]

        if self.transform:
            sample = self.processing(sample)

        return sample, label
